@@ -7,11 +7,11 @@ from PIL import Image, ImageDraw, ImageFont, ImageOps
 WIDTH = 300
 HEIGHT = 90
 FONT_SIZE = 16
-FONT = '../resources/font.ttf'
+FONT = pkg_resources.resource_filename(__name__, 'resources/font.ttf')
 
 
 def draw_date(draw: ImageDraw, date: datetime):
-    font = ImageFont.truetype(pkg_resources.resource_filename(__name__, 'resources/font.ttf'), FONT_SIZE)
+    font = ImageFont.truetype(FONT, FONT_SIZE)
     draw.text((10, 30), date.strftime("%d-%m-%Y"), font=font, fill=(0, 0, 0))
 
 
