@@ -4,7 +4,7 @@ from typing import BinaryIO
 import PyPDF2
 import io
 
-import sign_generator
+import signer_pdf.sign_generator as sign_generator
 
 
 def sign(name: str, date: datetime, a_hash: str, in_file: BinaryIO) -> io.BytesIO:
